# Datacoco3 - Utils
Equinox Common Code Utility for Python 3 - Utilities!

There are currently wrappers for the following utils:

+ Email
+ FTP Servers

## Installing the latest version

```
pip install git+https://github.com/equinoxfitness/datacoco.util.git#egg=coutils
```

## Development

#### Getting Started

It is recommended to use the steps below to set up a virtual environment for development:


```
python3 -m venv <virtual env name>
source venv/bin/activate
pip install -r requirements.txt
```

#### Testing
```
pip install -r requirements-dev.txt
To run the testing suite, simply run the command: `tox`
```
